'use strict';

const shellyHelper = require(__dirname + '/../shelly-helper');

/**
 * Adds a generic switch definition for gen 2 devices
 * @param {*} deviceObj
 * @param {*} switchId
 */
function addSwitchToGen2Device(deviceObj, switchId, hasPowerMetering) {

    deviceObj[`Relay${switchId}.Switch`] = {
        device_mode: 'switch',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).output; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 1, src: 'iobroker', method: 'Switch.Set', params: { id: switchId, on: value }}); }
        },
        common: {
            'name': 'Switch',
            'type': 'boolean',
            'role': 'switch',
            'read': true,
            'write': true,
            'def': false
        }
    };

    deviceObj[`Relay${switchId}.InputMode`] = {
        device_mode: 'switch',
        mqtt: {
            http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).in_mode : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { in_mode: value }}}); }
        },
        common: {
            'name': 'Input Mode',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'states': {
                'momentary': 'momentary',
                'follow': 'follow',
                'flip': 'flip',
                'detached': 'detached'
            }
        }
    };

    deviceObj[`Relay${switchId}.InitialState`] = {
        device_mode: 'switch',
        mqtt: {
            http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).initial_state : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { initial_state: value }}}); }
        },
        common: {
            'name': 'Initial State',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'states': {
                'on': 'on',
                'off': 'off',
                'restore_last': 'restore_last',
                'match_input': 'match_input'
            }
        }
    };

    deviceObj[`Relay${switchId}.ChannelName`] = {
        device_mode: 'switch',
        mqtt: {
            http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
            http_publish_funct: async (value, self) => { return value ? await shellyHelper.setChannelName(self, `Relay${switchId}`, JSON.parse(value).name) : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { name: value }}}); }
        },
        common: {
            'name': 'Channel Name',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'def': `switch_${switchId}`
        }
    };

    deviceObj[`Relay${switchId}.AutoTimerOn`] = {
        device_mode: 'switch',
        mqtt: {
            http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).auto_on : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { auto_on: value }}}); }
        },
        common: {
            'name': 'Auto Timer On',
            'type': 'boolean',
            'role': 'switch.enable',
            'def': false,
            'read': true,
            'write': true
        }
    };

    deviceObj[`Relay${switchId}.AutoTimerOnDelay`] = {
        device_mode: 'switch',
        mqtt: {
            http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).auto_on_delay : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { auto_on_delay: value }}}); }
        },
        common: {
            'name': 'Auto Timer On Delay',
            'type': 'number',
            'role': 'level.timer',
            'def': 0,
            'unit': 's',
            'read': true,
            'write': true
        }
    };

    deviceObj[`Relay${switchId}.AutoTimerOff`] = {
        device_mode: 'switch',
        mqtt: {
            http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).auto_off : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { auto_off: value }}}); }
        },
        common: {
            'name': 'Auto Timer Off',
            'type': 'boolean',
            'role': 'switch.enable',
            'def': false,
            'read': true,
            'write': true
        }
    };

    deviceObj[`Relay${switchId}.AutoTimerOffDelay`] = {
        device_mode: 'switch',
        mqtt: {
            http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).auto_off_delay : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { auto_off_delay: value }}}); }
        },
        common: {
            'name': 'Auto Timer Off Delay',
            'type': 'number',
            'role': 'level.timer',
            'def': 0,
            'unit': 's',
            'read': true,
            'write': true
        }
    };

    deviceObj[`Relay${switchId}.source`] = {
        device_mode: 'switch',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).source; }
        },
        common: {
            'name': 'Source of last command',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': false
        }
    };

    deviceObj[`Relay${switchId}.temperatureC`] = {
        device_mode: 'switch',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).temperature.tC; }
        },
        common: {
            'name': 'Temperature °C',
            'type': 'number',
            'role': 'value.temperature',
            'read': true,
            'write': false,
            'unit': '°C'
        }
    };

    deviceObj[`Relay${switchId}.temperatureF`] = {
        device_mode: 'switch',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).temperature.tF; }
        },
        common: {
            'name': 'Temperature °F',
            'type': 'number',
            'role': 'value.temperature',
            'read': true,
            'write': false,
            'unit': '°F'
        }
    };

    if (hasPowerMetering) {

        deviceObj[`Relay${switchId}.Power`] = {
            device_mode: 'switch',
            mqtt: {
                mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
                mqtt_publish_funct: (value) => { return JSON.parse(value).apower; }
            },
            common: {
                'name': 'Power',
                'type': 'number',
                'role': 'value.power',
                'read': true,
                'write': false,
                'def': 0,
                'unit': 'W'
            }
        };

        deviceObj[`Relay${switchId}.Voltage`] = {
            device_mode: 'switch',
            mqtt: {
                mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
                mqtt_publish_funct: (value) => { return JSON.parse(value).voltage; }
            },
            common: {
                'name': 'Voltage',
                'type': 'number',
                'role': 'value.voltage',
                'read': true,
                'write': false,
                'def': 0,
                'unit': 'V'
            }
        };

        deviceObj[`Relay${switchId}.Current`] = {
            device_mode: 'switch',
            mqtt: {
                mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
                mqtt_publish_funct: (value) => { return JSON.parse(value).current; }
            },
            common: {
                'name': 'Current',
                'type': 'number',
                'role': 'value.current',
                'read': true,
                'write': false,
                'def': 0,
                'unit': 'A'
            }
        };

        deviceObj[`Relay${switchId}.Energy`] = {
            device_mode: 'switch',
            mqtt: {
                mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
                mqtt_publish_funct: (value) => { return JSON.parse(value).aenergy.total; }
            },
            common: {
                'name': 'Energy',
                'type': 'number',
                'role': 'value.power.consumption',
                'read': true,
                'write': false,
                'def': 0,
                'unit': 'Wh'
            }
        };

        /*
        deviceObj[`Relay${switchId}.Overvoltage`] = {
            device_mode: 'switch',
            mqtt: {
                mqtt_publish: `<mqttprefix>/status/switch:${switchId}`,
                mqtt_publish_funct: (value) => {
                    const valueObj = JSON.parse(value);
                    return valueObj.errors && Array.prototype.includes.call(valueObj.errors, 'overvoltage');
                }
            },
            common: {
                'name': 'Overvoltage',
                'type': 'boolean',
                'role': 'indicator.alarm',
                'read': true,
                'write': false,
                'def': false
            }
        };
        */

        deviceObj[`Relay${switchId}.LimitPower`] = {
            device_mode: 'switch',
            mqtt: {
                http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
                http_publish_funct: async (value) => { return value ? JSON.parse(value).power_limit : undefined; },
                mqtt_cmd: '<mqttprefix>/rpc',
                mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { power_limit: value }}}); }
            },
            common: {
                'name': 'Power Limit',
                'type': 'number',
                'role': 'value.power',
                'unit': 'W',
                'read': true,
                'write': true
            }
        };

        deviceObj[`Relay${switchId}.LimitCurrent`] = {
            device_mode: 'switch',
            mqtt: {
                http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
                http_publish_funct: async (value) => { return value ? JSON.parse(value).current_limit : undefined; },
                mqtt_cmd: '<mqttprefix>/rpc',
                mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { current_limit: value }}}); }
            },
            common: {
                'name': 'Current Limit',
                'type': 'number',
                'role': 'value.current',
                'unit': 'A',
                'read': true,
                'write': true
            }
        };

        deviceObj[`Relay${switchId}.LimitVoltage`] = {
            device_mode: 'switch',
            mqtt: {
                http_publish: `/rpc/Switch.GetConfig?id=${switchId}`,
                http_publish_funct: async (value) => { return value ? JSON.parse(value).voltage_limit : undefined; },
                mqtt_cmd: '<mqttprefix>/rpc',
                mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Switch.SetConfig', params: { id: switchId, config: { voltage_limit: value }}}); }
            },
            common: {
                'name': 'Current Limit',
                'type': 'number',
                'role': 'value.voltage',
                'unit': 'V',
                'read': true,
                'write': true
            }
        };
    }

}

/**
 * Adds a generic input definition for gen 2 devices
 * @param {*} deviceObj
 * @param {*} inputId
 */
function addInputToGen2Device(deviceObj, inputId) {

    deviceObj[`Input${inputId}.Status`] = {
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/input:${inputId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).state; }
        },
        common: {
            'name': 'Input Status',
            'type': 'boolean',
            'role': 'state',
            'read': true,
            'write': false
        }
    };

    deviceObj[`Input${inputId}.ChannelName`] = {
        mqtt: {
            http_publish: `/rpc/Input.GetConfig?id=${inputId}`,
            http_publish_funct: async (value, self) => { return value ? await shellyHelper.setChannelName(self, `Input${inputId}`, JSON.parse(value).name) : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Input.SetConfig', params: { id: inputId, config: { name: value }}}); }
        },
        common: {
            'name': 'Channel Name',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'def': `input_${inputId}`
        }
    };

    deviceObj[`Input${inputId}.Event`] = {
        mqtt: {
            mqtt_publish: '<mqttprefix>/events/rpc',
            mqtt_publish_funct: (value) => {
                const valueObj = JSON.parse(value);
                if (valueObj?.method === 'NotifyEvent' && valueObj?.params?.events) {
                    for (const e in valueObj.params.events) {
                        const event = valueObj.params.events[e];

                        if (typeof event === 'object' && event.component === `input:${inputId}`) {
                            return event.event;
                        }
                    }
                }
                return undefined;
            }
        },
        common: {
            'name': 'Input Event',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': false
        }
    };

    deviceObj[`Input${inputId}.InputType`] = {
        mqtt: {
            http_publish: `/rpc/Input.GetConfig?id=${inputId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).type : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Input.SetConfig', params: { id: inputId, config: { type: value }}}); }
        },
        common: {
            'name': 'Input Type',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'states': {
                'button': 'button',
                'switch': 'switch'
            }
        }
    };

    deviceObj[`Input${inputId}.InputInverted`] = {
        mqtt: {
            http_publish: `/rpc/Input.GetConfig?id=${inputId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).invert : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Input.SetConfig', params: { id: inputId, config: { invert: value }}}); }
        },
        common: {
            'name': 'Input Inverted',
            'type': 'boolean',
            'role': 'state',
            'read': true,
            'write': true
        }
    };

}

/**
 * Adds a generic cover definition for gen 2 devices
 * @param {*} deviceObj
 * @param {*} coverId
 */
function addCoverToGen2Device(deviceObj, coverId) {

    deviceObj[`Cover${coverId}.Open`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: () => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.Open', params: { id: coverId }}); }
        },
        common: {
            'name': 'Open',
            'type': 'boolean',
            'role': 'button',
            'read': false,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.InitialState`] = {
        device_mode: 'cover',
        mqtt: {
            http_publish: `/rpc/Cover.GetConfig?id=${coverId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).initial_state : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.SetConfig', params: { id: coverId, config: { initial_state: value }}}); }
        },
        common: {
            'name': 'Initial State',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'states': {
                'open': 'oopenn',
                'closed': 'closed',
                'stopped': 'stopped'
            }
        }
    };

    deviceObj[`Cover${coverId}.ChannelName`] = {
        device_mode: 'cover',
        mqtt: {
            http_publish: `/rpc/Cover.GetConfig?id=${coverId}`,
            http_publish_funct: async (value, self) => { return value ? await shellyHelper.setChannelName(self, `Cover${coverId}`, JSON.parse(value).name) : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.SetConfig', params: { id: coverId, config: { name: value }}}); }
        },
        common: {
            'name': 'Channel Name',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'def': `cover_${coverId}`
        }
    };

    deviceObj[`Cover${coverId}.Stop`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: () => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.Stop', params: { id: coverId }}); }
        },
        common: {
            'name': 'Stop',
            'type': 'boolean',
            'role': 'button',
            'read': false,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.Close`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: () => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.Close', params: { id: coverId }}); }
        },
        common: {
            'name': 'Close',
            'type': 'boolean',
            'role': 'button',
            'read': false,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.Calibrate`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: () => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.Calibrate', params: { id: coverId }}); }
        },
        common: {
            'name': 'Calibrate',
            'type': 'boolean',
            'role': 'button',
            'read': false,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.InputSwap`] = {
        device_mode: 'cover',
        mqtt: {
            http_publish: `/rpc/Cover.GetConfig?id=${coverId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).swap_inputs : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.SetConfig', params: { id: coverId, config: { swap_inputs: value }}}); }
        },
        common: {
            'name': 'Input Swap',
            'type': 'boolean',
            'role': 'switch.enable',
            'read': true,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.InputMode`] = {
        device_mode: 'cover',
        mqtt: {
            http_publish: `/rpc/Cover.GetConfig?id=${coverId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).in_mode : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.SetConfig', params: { id: coverId, config: { in_mode: value }}}); }
        },
        common: {
            'name': 'Input Mode',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': true,
            'states': {
                'single': 'single',
                'dual': 'dual',
                'detached': 'detached'
            }
        }
    };

    deviceObj[`Cover${coverId}.LimitPower`] = {
        device_mode: 'cover',
        mqtt: {
            http_publish: `/rpc/Cover.GetConfig?id=${coverId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).power_limit : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.SetConfig', params: { id: coverId, config: { power_limit: value }}}); }
        },
        common: {
            'name': 'Power Limit',
            'type': 'number',
            'role': 'value.power',
            'unit': 'W',
            'read': true,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.LimitCurrent`] = {
        device_mode: 'cover',
        mqtt: {
            http_publish: `/rpc/Cover.GetConfig?id=${coverId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).current_limit : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.SetConfig', params: { id: coverId, config: { current_limit: value }}}); }
        },
        common: {
            'name': 'Current Limit',
            'type': 'number',
            'role': 'value.current',
            'unit': 'A',
            'read': true,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.LimitVoltage`] = {
        device_mode: 'cover',
        mqtt: {
            http_publish: `/rpc/Cover.GetConfig?id=${coverId}`,
            http_publish_funct: async (value) => { return value ? JSON.parse(value).voltage_limit : undefined; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.SetConfig', params: { id: coverId, config: { voltage_limit: value }}}); }
        },
        common: {
            'name': 'Current Limit',
            'type': 'number',
            'role': 'value.voltage',
            'unit': 'V',
            'read': true,
            'write': true
        }
    };

    deviceObj[`Cover${coverId}.Position`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/cover:${coverId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).current_pos; },
            mqtt_cmd: '<mqttprefix>/rpc',
            mqtt_cmd_funct: (value) => { return JSON.stringify({ id: 0, src: 'iobroker', method: 'Cover.GoToPosition', params: { id: coverId, pos: value }}); }
        },
        common: {
            'name': 'Position',
            'type': 'number',
            'role': 'level.blind',
            'read': true,
            'write': true,
            'unit': '%',
            'def': 0,
            'min': 0,
            'max': 100
        }
    };

    deviceObj[`Cover${coverId}.Status`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/cover:${coverId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).state; }
        },
        common: {
            'name': 'Cover Status',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': false
        }
    };

    deviceObj[`Cover${coverId}.Power`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/cover:${coverId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).apower; }
        },
        common: {
            'name': 'Power',
            'type': 'number',
            'role': 'value.power',
            'read': true,
            'write': false,
            'def': 0,
            'unit': 'W'
        }
    };

    deviceObj[`Cover${coverId}.Voltage`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/cover:${coverId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).voltage; }
        },
        common: {
            'name': 'Voltage',
            'type': 'number',
            'role': 'value.voltage',
            'read': true,
            'write': false,
            'def': 0,
            'unit': 'V'
        }
    };

    deviceObj[`Cover${coverId}.Current`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/cover:${coverId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).current; }
        },
        common: {
            'name': 'Current',
            'type': 'number',
            'role': 'value.current',
            'read': true,
            'write': false,
            'def': 0,
            'unit': 'A'
        }
    };

    deviceObj[`Cover${coverId}.Energy`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/cover:${coverId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).aenergy.total; }
        },
        common: {
            'name': 'Energy',
            'type': 'number',
            'role': 'value.power.consumption',
            'read': true,
            'write': false,
            'def': 0,
            'unit': 'Wh'
        }
    };

    deviceObj[`Cover${coverId}.source`] = {
        device_mode: 'cover',
        mqtt: {
            mqtt_publish: `<mqttprefix>/status/cover:${coverId}`,
            mqtt_publish_funct: (value) => { return JSON.parse(value).source; }
        },
        common: {
            'name': 'Source of last command',
            'type': 'string',
            'role': 'state',
            'read': true,
            'write': false
        }
    };

}

module.exports = {
    addSwitchToGen2Device: addSwitchToGen2Device,
    addInputToGen2Device: addInputToGen2Device,
    addCoverToGen2Device: addCoverToGen2Device
};
